@@ -13,6 +13,8 @@
 #include "Constants.h"
 #include "DetailedWindow.h"
 #include <Qt>
+#include "QLabelW.h"
+#include "QLabelImage.h"
 
 #ifdef Q_WS_MAEMO_5
 #include <QDBusInterface>
@@ -21,298 +23,10 @@
 #include <QDesktopServices>
 
 
-QLabelW::QLabelW(const QString &text, bool isLabel, bool isImage, bool isEdit, QWidget *parent, Qt::WindowFlags f) : QLabel (text, parent, f) {
-	this->isLabel = isLabel;
-	this->isImage = isImage;
-	this->isEdit = isEdit;
-	this->modified = false;
-	this->image = NULL;
-
-	if ((!isLabel) || isImage) {
-		setContextMenuPolicy(Qt::CustomContextMenu);
-		QObject::connect(this, SIGNAL(customContextMenuRequested(const QPoint&)), this, SLOT(labelMenu(const QPoint&)));
-
-		if (isImage) {
-			this->setBackgroundRole(QPalette::NoRole);
-			//this->setContentsMargins(5, 2, 0, 2);
-			this->setMaximumSize(OTHER_WIDTH, OTHER_HEIGH);
-			//this->setMinimumSize(BIG_WIDTH, BIG_HEIGH);
-			this->setScaledContents(true);
-//			}
-//			else {
-//				imageLabel->setMaximumSize(MAX_WIDTH, MAX_HEIGH);
-//				imageLabel->setMinimumSize(MAX_WIDTH, MAX_HEIGH);
-//				imageLabel->setScaledContents(true);
-//			}
-		}
-	}
-}
-
-QLabelW::QLabelW(QWidget *parent, Qt::WindowFlags f): QLabel (parent, f) {
-}
-
-QLabelW::~QLabelW() {
-	if (image != NULL) {
-		qDebug () << "destroy image " << image;
-		delete image; // TODO sure??
-		image = NULL;
-	}
-}
-
-QImage * QLabelW::getPicture () {
-	return image;
-}
-
-void QLabelW::readImage (TargetField * field) {
-	if (image == NULL)
-		field->value = "";
-	else {
-		eWallet::preProcessImage (image);
-
-		QByteArray im2;
-		QBuffer buffer2(&im2);
-
-		buffer2.open(QIODevice::WriteOnly);
-		image->save(&buffer2, "PNG"); // writes image into ba in PNG format
-
-		field->value = QString (im2.toBase64());
-	}
-	qDebug () << "getting IMAGE field " << image << " " << field->value.length() << " bytes";
-}
-
-void QLabelW::setPicture (TargetField * field) {
-	//TargetField * f = ((ButtonInfo *)this->userData(0))->field;
-
-	image = NULL;
-	if (field->value.length() > 0) {
-		image = new QImage ();
-
-		qDebug () << "exist image " << field->value.length() << " bytes";
-		//QByteArray im_s;
-		//decrypt(query.value(0).toByteArray(), im_s);
-		if (!image->loadFromData (QByteArray::fromBase64(field->value.toAscii()))) {
-
-		}
-	}
-
-	if (image == NULL) {
-		QPixmap available(":/resources/empty_card.png");
-		this->setPixmap(available);
-	}
-	else {
-		this->setPixmap(QPixmap::fromImage (*image));
-	}
-}
-
-
-void QLabelW::labelMenu(const QPoint & _p) {
-   	TargetField * f = ((ButtonInfo *)this->userData(0))->field;
-
-	if ((f->value != NULL && f->value.length() > 0) || f->type == TYPE_IMAGE) {
-		QMenu menu(this);
-		if (f->type == TYPE_URL) {
-			menu.addAction(tr("Go to"), this, SLOT(m_goto()));
-			menu.addAction(tr("Copy"), this, SLOT(m_copy()));
-			//QDesktopServices::openUrl(QUrl::fromUserInput(f->value));
-		}
-		else {
-			if (f->type == TYPE_PHONE_NUMBER) {
-				QString telf = f->value;
-				telf = telf.simplified();
-				telf = telf.replace(" ", "");
-
-				if (telf.length() > 0) {
-					menu.addAction(tr("Call to").arg(telf), this, SLOT(m_call()));
-				}
-				//menu.addAction(tr("SMS to"), tmp, SLOT(m_sms()));
-				menu.addAction(tr("Copy"), this, SLOT(m_copy()));
-			}
-			else {
-				if (f->type == TYPE_IMAGE) {
-					if (isEdit) {
-						menu.addAction(tr("Edit"), this, SLOT(m_editImage()));
-						//menu.addAction(tr("Mirror"), this, SLOT(mirrorFace()));
-						menu.addAction(tr("Rotate"), this, SLOT(m_rotateImage()));
-						menu.addAction(tr("Delete"), this, SLOT(m_deleteImage()));
-					}
-					else {
-						menu.addAction(tr("Export"), this, SLOT(m_exportImage()));
-					}
-				}
-				else
-					menu.addAction(tr("Copy"), this, SLOT(m_copy()));
-			}
-		}
-		menu.exec(_p);
-	}
-}
-void QLabelW::m_editImage () {
-   	TargetField * f = ((ButtonInfo *)this->userData(0))->field;
-
-	QString path(QDesktopServices::storageLocation(QDesktopServices::PicturesLocation));
-	QString s = QFileDialog::getOpenFileName(
-	                this,
-	                tr("Choose image"),
-	                path,
-	                tr("Images (*.png *.jpg *.gif *.jpeg);;"));
-
-	if (!s.isNull () && !s.isEmpty ()) {
-		////qDebug () << "loading " << s;
-		if (image) delete image;
-
-		image = new QImage ();
-		DetailWindow::loadImage(settings, s, *image); //;
-		////qDebug () << "loaded " << s;
-		this->setPixmap(QPixmap::fromImage (*image));
-		////qDebug () << "asigned " << s;
-		//update();
-		//deleteFace = false;
-		modified = true;
-	}
-}
-void QLabelW::m_rotateImage () {
-   	TargetField * f = ((ButtonInfo *)this->userData(0))->field;
-
-   	if (image != NULL) {
-		QImage * tmp = image;
-
-		QMatrix m;
-		m.rotate(90);
-		image = new QImage (tmp->transformed(m));
-
-		this->setPixmap(QPixmap::fromImage (*image));
-		delete tmp;
-		modified = true;
-   	}
-}
-void QLabelW::m_deleteImage () {
-   	TargetField * f = ((ButtonInfo *)this->userData(0))->field;
-
-   	if (image != NULL) {
-		modified = true;
-		delete image;
-		image = NULL;
-		QPixmap available(":/resources/empty_card.png");
-		this->setPixmap(available);
-   	}
-}
-void QLabelW::m_exportImage () {
-   	TargetField * f = ((ButtonInfo *)this->userData(0))->field;
-
-	DetailWindow::exportImage(this, image, f->name, tr("Choose image file"));
-}
-
-void QLabelW::m_copy () {
-   	TargetField * f = ((ButtonInfo *)this->userData(0))->field;
-
-	if (f->type != TYPE_IMAGE) {
-#ifdef Q_WS_MAEMO_5
-		show_banner(this, tr("%1 has been saved to clipboard").arg(f->name));
-#endif
-		QClipboard *cb = QApplication::clipboard();
-		cb->setText(f->value);
-	}
-}
-
-void QLabelW::m_goto () {
-	TargetField * f = ((ButtonInfo *)this->userData(0))->field;
-	if (f->type == TYPE_URL && !isLabel) {
-		QDesktopServices::openUrl(QUrl::fromUserInput(f->value));
-	}
-}
-
-void QLabelW::m_sms () {
-
-}
-
-void QLabelW::m_call () {
-#ifdef Q_WS_MAEMO_5
-    TargetField * f = ((ButtonInfo *)this->userData(0))->field;
-	if (!isLabel) {
-		if (f->type == TYPE_PHONE_NUMBER) {
-//    				QSettings settings;
-
-
-//			XQTelephony *telephony = new XQTelephony(this);
-//			telephony->call("+919464763259");//caller number
-
-			QString telf = f->value;
-			telf = telf.simplified();
-			telf = telf.replace(" ", "");
-
-			if (telf.length() > 0) {
-				qDebug () << "calling to " << telf;
-				QDBusConnection conn = QDBusConnection::systemBus(); //QString(MCE_SERVICE), QString(MCE_SIGNAL_PATH)
-				QDBusInterface dbusPhone( QString ("com.nokia.csd.Call"), QString ("/com/nokia/csd/call"), QString ("com.nokia.csd.Call"), conn );
-				QDBusMessage msg = dbusPhone.call( QString ("CreateWith"), telf, (uint)0 );
-				qDebug() << msg;
-			}
-		}
-	}
-//    				if (settings.value("TT/method1").toBool()) {
-//    					qDebug () << "method1";
-//
-//	    				qDebug () << settings.value("TT/dest") << "-" << settings.value("TT/object") << "-" << settings.value("TT/message") << "-" << settings.value("TT/method");
-//
-//	    				QDBusConnection conn = QDBusConnection::systemBus(); //QString(MCE_SERVICE), QString(MCE_SIGNAL_PATH)
-//
-//	    				QDBusInterface dbusPhone( settings.value("TT/dest").toString(), settings.value("TT/object").toString(), settings.value("TT/message").toString(), conn );
-//	    				QDBusMessage msg = dbusPhone.call( settings.value("TT/method").toString(), f->value, (uint)0 );
-//
-//	    				qDebug() << msg;
-//    				}
-//
-//    				if (settings.value("TT/method2").toBool()) {
-//    					qDebug () << "method2";
-//
-//	    				qDebug () << settings.value("TT/dest") << "-" << settings.value("TT/object") << "-" << settings.value("TT/message") << "-" << settings.value("TT/method");
-//
-//						QDBusMessage msg = QDBusMessage::createMethodCall(
-//								settings.value("TT/dest").toString(), //QString ("com.nokia.csd.Call"), // --dest
-//								settings.value("TT/object").toString(), //QString ("/com/nokia/csd/call"), // destination object path
-//								settings.value("TT/message").toString(), //QString ("com.nokia.csd.Call"), // message name (w/o method)
-//								settings.value("TT/method").toString() //QString ("CreateWith") // method
-//							);
-//						msg << f->value;
-//						msg << 0;
-//						msg = QDBusConnection::systemBus().call(msg);
-//						qDebug() << msg;
-//    				}
-//
-//    				if (settings.value("TT/method3").toBool()) {
-//    					qDebug () << "method3";
-//
-//    					::system ((const char *)(QString ("dbus-send --system --type=method_call --dest=com.nokia.csd.Call /com/nokia/csd/call com.nokia.csd.Call.CreateWith string:\"%1\" uint32:0").arg(f->value).constData()));
-//    				}
-#endif
-}
-
-void QLabelW::mousePressEvent(QMouseEvent *) {
-	////qDebug () << "click on field " << this->userData(0);
-	TargetField * f = ((ButtonInfo *)this->userData(0))->field;
-
-	if (isLabel) {
-		m_copy ();
-	}
-//	else
-//	if (f->type == TYPE_URL) {
-//		m_goto ();
-//	}
-//	else
-//	if (f->type == TYPE_PHONE_NUMBER) {
-//		m_call ();
-//	}
-//	else {
-//		m_copy ();
-//   	}
- }
-
 
 DetailWindow::DetailWindow(Target * _target, const QString & groupName, int istemplate, bool edit, eWallet *paTarget, QWidget *parent) :
 		QMainWindow(parent)
 {
-	//settings.setValue("hints/phoneNumber/supportCharacters", true);
-
 	setWindowTitle("Wallet");
 
 #ifdef Q_WS_MAEMO_5
@@ -336,8 +50,7 @@ DetailWindow::DetailWindow(Target * _target, const QString & groupName, int iste
 	this->parent = paTarget;
 	this->edit = edit;
 
-	//qDebug () << "DETAIL " << target << " " << groupName << " " << istemplate << " " << edit;
-
+	qDebug () << "DETAIL " << target << " " << groupName << " " << istemplate << " " << edit;
 
 	if (istemplate > 0) {
 		this->target = new Target ();
@@ -364,7 +77,7 @@ DetailWindow::DetailWindow(Target * _target, const QString & groupName, int iste
 	if (isNew) {
 		this->target = new Target ();
 		this->target->groupName = groupName;
-		this->target->type = this->parent->types->at(0);
+		this->target->type = this->parent->types->at(0)->name;
 		changeFields (0);
 	}
 
@@ -513,6 +226,7 @@ DetailWindow::DetailWindow(Target * _target, const QString & groupName, int iste
 	}
 
 	if (edit) {
+
 		static const char *types_string[] = {
 		    QT_TR_NOOP("Membership Info"),
 		    QT_TR_NOOP("Password"),
@@ -542,9 +256,15 @@ DetailWindow::DetailWindow(Target * _target, const QString & groupName, int iste
 
 		bool selected = false;
 		for(int i = 0; i < this->parent->types->size(); i++) {
-			typeLineEdit->addItem (tr(types_string[i])/*this->parent->types->at(i))*/, this->parent->types->at(i));
+//			qDebug () << this->parent->types->at(i)->id << " " << this->parent->types->at(i)->name;
+//			if ((this->parent->types->at(i)->id - 1) < GENERIC_TYPES_NUMBER) {
+//				typeLineEdit->addItem (tr(types_string[this->parent->types->at(i)->id - 1]), this->parent->types->at(i)->name);
+//			}
+//			else {
+				typeLineEdit->addItem (this->parent->types->at(i)->name, this->parent->types->at(i)->name);
+//			}
 
-			if (this->target->type == this->parent->types->at(i)) {
+			if (this->target->type == this->parent->types->at(i)->name) {
 				typeLineEdit->setCurrentIndex(i);
 				selected = true;
 			}
@@ -563,7 +283,7 @@ DetailWindow::DetailWindow(Target * _target, const QString & groupName, int iste
 	else {
 		elType = -1;
 		for(int i = 0; i < this->parent->types->size(); i++) {
-			if (this->target->type == this->parent->types->at(i)) {
+			if (this->target->type == this->parent->types->at(i)->name) {
 				elType = i;
 				break;
 			}
@@ -574,33 +294,33 @@ DetailWindow::DetailWindow(Target * _target, const QString & groupName, int iste
 
 	componentLayout = new QGridLayout ();
 
-	//QObject::connect(this, SIGNAL(customContextMenuRequested(const QPoint&)), this, SLOT(cardMenu(const QPoint&)));
-
 	if (edit || this->target->getPicture() != NULL) {
-		imageLabel = new QLabel(this);
+		imageLabel = new QLabelImage(this);
 
-		imageLabel->setBackgroundRole(QPalette::NoRole);
-		imageLabel->setContentsMargins(5, 2, 0, 2);
 		if (edit) {
 			imageLabel->setMaximumSize(BIG_WIDTH, BIG_HEIGH);
 			imageLabel->setMinimumSize(BIG_WIDTH, BIG_HEIGH);
-			imageLabel->setScaledContents(true);
 		}
 		else {
 			imageLabel->setMaximumSize(MAX_WIDTH, MAX_HEIGH);
 			imageLabel->setMinimumSize(MAX_WIDTH, MAX_HEIGH);
-			imageLabel->setScaledContents(true);
 		}
+
+		imageLabel->setPicture (currentImage);
+
 		if (currentImage == NULL) {
 			QPixmap available(":/resources/empty_card.png");
 			imageLabel->setPixmap(available);
 		}
-		else {
-			imageLabel->setPixmap(QPixmap::fromImage (*currentImage));
-		}
+//		else {
+//			imageLabel->setPixmap(QPixmap::fromImage (*currentImage));
+//		}
 		
-		imageLabel->setContextMenuPolicy(Qt::CustomContextMenu);
+		//imageLabel->setContextMenuPolicy(Qt::CustomContextMenu);
 		QObject::connect(imageLabel, SIGNAL(customContextMenuRequested(const QPoint&)), this, SLOT(cardFaceMenu(const QPoint&)));
+//		if (!edit)
+//			QObject::connect(imageLabel, SIGNAL(clicked ()), this, SLOT(seePicture()));
+
 #ifdef Q_WS_MAEMO_5
 		if (edit) {
 			componentLayout->addWidget(imageLabel, 3, 0, 2, 3);
@@ -616,32 +336,31 @@ DetailWindow::DetailWindow(Target * _target, const QString & groupName, int iste
 	}
 
 	if (edit || this->target->getPictureBack() != NULL) {
-		imageBackLabel = new QLabel(this);
+		imageBackLabel = new QLabelImage(this);
 
-		imageBackLabel->setBackgroundRole(QPalette::NoRole);
-		//imageBackLabel->setFocusPolicy(Qt::StrongFocus);
-		imageBackLabel->setContentsMargins(5, 2, 0, 2);
 		if (edit) {
 			imageBackLabel->setMaximumSize(BIG_WIDTH, BIG_HEIGH);
 			imageBackLabel->setMinimumSize(BIG_WIDTH, BIG_HEIGH);
-			imageBackLabel->setScaledContents(true);
 		}
 		else {
 			//imageBackLabel->setMaximumSize(MAX_WIDTH, MAX_HEIGH);
 			imageBackLabel->setMaximumSize(MAX_WIDTH, MAX_HEIGH);
 			imageBackLabel->setMinimumSize(MAX_WIDTH, MAX_HEIGH);
-			imageBackLabel->setScaledContents(true);
 		}
+		imageBackLabel->setPicture (currentImageBack);
+
 		if (currentImageBack == NULL) {
 			QPixmap availableBack(":/resources/empty_card_back.png");
 			imageBackLabel->setPixmap(availableBack);
 		}
-		else {
-			imageBackLabel->setPixmap(QPixmap::fromImage (*currentImageBack));
-		}
+//		else {
+//			imageBackLabel->setPixmap(QPixmap::fromImage (*currentImageBack));
+//		}
 
-		imageBackLabel->setContextMenuPolicy(Qt::CustomContextMenu);
+		//imageBackLabel->setContextMenuPolicy(Qt::CustomContextMenu);
 		QObject::connect(imageBackLabel, SIGNAL(customContextMenuRequested(const QPoint&)), this, SLOT(cardBackMenu(const QPoint&)));
+//		if (!edit)
+//			QObject::connect(imageBackLabel, SIGNAL(clicked ()), this, SLOT(seeBackPicture()));
 
 #ifdef Q_WS_MAEMO_5
 		if (edit) {
@@ -714,13 +433,12 @@ void DetailWindow::modifyFields() {
 			}
 		}
 
-		createFieldDlg = new CreateFieldDialog(this->target, this);
+		createFieldDlg = new CreateFieldDialog(this->target, this, this);
 		createFieldDlg->setMinimumSize(size().width(),size().height()-100);
-		createFieldDlg->exec();
-
-		// TODO sort fields!!!
-
-		showFields ();
+		if (createFieldDlg->exec() == QDialog::Accepted) {
+			// TODO sort fields!!!
+			showFields ();
+		}
 
 		delete createFieldDlg;
 		createFieldDlg = 0;
@@ -822,6 +540,7 @@ void DetailWindow::_addField (TargetField * field) {
 	}
 	else
 	if (field->type == TYPE_IMAGE) {
+		//QObject::connect(imageLabel, SIGNAL(clicked ()), this, SLOT(seePicture()));
 		QLabelW * imageLabel = new QLabelW("", false, true, true, this);
 		imageLabel->setUserData(0, new ButtonInfo (field));
 		componentLayout->addWidget(imageLabel, pos, 1, 1, 1);
@@ -885,10 +604,12 @@ void DetailWindow::showFields () {
 					if (QLocale::system().name() != "en") {
 						if (elType >= 0) {
 							int i = 0;
-							for (; i < parent->fieldsByType->at (elType)->size(); i++) {
-								TargetField tmp = parent->fieldsByType->at (elType)->at(i);
-								if (tmp.originalName == field->name) {
-									nameLabel = new QLabelW(tmp.name, true, false, false, this);
+
+							Target * tt = parent->types->at (elType);
+							for (; i < tt->fields.size(); i++) {
+								TargetField * tmp = tt->fields.at(i);
+								if (tmp->originalName == field->name) {
+									nameLabel = new QLabelW(tmp->name, true, false, false, this);
 									i = -1;
 									break;
 								}
@@ -932,11 +653,22 @@ void DetailWindow::showFields () {
 						}
 						else
 						if (field->type == TYPE_IMAGE) {
-							QLabelW * imageLabel = new QLabelW("", false, true, edit, this);
+							QLabelImage * imageLabel = new QLabelImage(); //"", false, true, edit, this);
 							imageLabel->setUserData(0, new ButtonInfo (field));
 
 							componentLayout->addWidget(imageLabel, pos, 1, 1, 1);
 							imageLabel->setPicture(field);
+
+							//setContextMenuPolicy(Qt::CustomContextMenu);
+							//QObject::connect(imageLabel, SIGNAL(customContextMenuRequested(const QPoint&)), this, SLOT(labelMenu(const QPoint&)));
+//
+//							if (isImage) {
+//								this->setBackgroundRole(QPalette::NoRole);
+//								//this->setContentsMargins(5, 2, 0, 2);
+//								this->setMaximumSize(OTHER_WIDTH, OTHER_HEIGH);
+//								//this->setMinimumSize(BIG_WIDTH, BIG_HEIGH);
+//								this->setScaledContents(true);
+
 						}
 						else {
 							QLabel * nameLineEdit = new QLabelW(field->value, false, false, false, this);
@@ -992,13 +724,14 @@ void DetailWindow::changeFields (int a) {
 		}
 	}
 
-	for (int i = 0; i < parent->fieldsByType->at (a)->size(); i++) {
-		TargetField tmp = parent->fieldsByType->at (a)->at(i);
+	Target * tt = parent->types->at (a);
+	for (int i = 0; i < tt->fields.size(); i++) {
+		TargetField * tmp = tt->fields.at(i);
 
-		if (!target->existField (tmp.name) && !target->existField (tmp.originalName)) {
+		if (!target->existField (tmp->name) && !target->existField (tmp->originalName)) {
 			TargetField * f;
 
-			f = new TargetField (tmp.name, tmp.type, tmp.encrypted, tmp.order);
+			f = new TargetField (tmp->name, tmp->type, tmp->encrypted, tmp->order);
 
 			target->fields.append(f);
 		}
@@ -1019,7 +752,7 @@ DetailWindow::~DetailWindow () {
 void DetailWindow::saveTarget () {
 	if (nameLineEdit->text().length() < 1) {
 #ifdef Q_WS_MAEMO_5
-		show_information_note (NULL, tr("Card description is missing"));
+		show_information_note (this, tr("Card description is missing"));
 #endif
 #ifndef Q_WS_MAEMO_5
 		if (messageBox.isNull()) {
@@ -1034,7 +767,7 @@ void DetailWindow::saveTarget () {
 
 	 if (typeLineEdit->currentIndex() < 0) {
 #ifdef Q_WS_MAEMO_5
-		 show_information_note (NULL, tr("Type card is missing"));
+		 show_information_note (this, tr("Type card is missing"));
 #endif
 #ifndef Q_WS_MAEMO_5
 		if (messageBox.isNull()) {
@@ -1458,6 +1191,7 @@ void DetailWindow::cardFaceMenu(const QPoint & pos) {
 	}
 	else {
 		menu.addAction(tr("Export Face"), this, SLOT(exportCardFace()));
+		//menu.addAction(tr("See"), this, SLOT(seePicture()));
 	}
 	menu.exec(pos);
 }
@@ -1632,274 +1366,46 @@ void DetailWindow::closeEvent(QCloseEvent *event) {
 	}
 }
 
-CreateFieldDialog::CreateFieldDialog(Target * target, DetailWindow *paTarget) :
-		QDialog((QWidget*)paTarget)
-{
-	setWindowTitle("Wallet");
+//void DetailWindow::windowViewerDestroyed (QObject*) {
+//
+//}
 
-	pos = 0;
-	this->target = target;
-	this->parent = paTarget;
-	_fieldsChanged = false;
+//void DetailWindow::seeOtherPicture() {
+//	if (viewerWindow.isNull() && currentImage != NULL) {
+//		viewerWindow = new ImageViewer(new QImage (*currentImage), this);
+//		viewerWindow->setAttribute(Qt::WA_DeleteOnClose);
+//        connect(viewerWindow, SIGNAL(destroyed(QObject*)), this, SLOT(windowViewerDestroyed(QObject*)));
+//        viewerWindow->show();
+//	}
+//}
+//
+//void DetailWindow::seePicture() {
+//	if (viewerWindow.isNull() && currentImage != NULL) {
+//		viewerWindow = new ImageViewer(new QImage (*currentImage), this);
+//		viewerWindow->setAttribute(Qt::WA_DeleteOnClose);
+//        connect(viewerWindow, SIGNAL(destroyed(QObject*)), this, SLOT(windowViewerDestroyed(QObject*)));
+//        viewerWindow->show();
+//	}
+//}
+//
+//void DetailWindow::seeBackPicture() {
+//	if (viewerWindow.isNull() && currentImageBack != NULL) {
+//		viewerWindow = new ImageViewer(new QImage (*currentImageBack), this);
+//		viewerWindow->setAttribute(Qt::WA_DeleteOnClose);
+//        connect(viewerWindow, SIGNAL(destroyed(QObject*)), this, SLOT(windowViewerDestroyed(QObject*)));
+//        viewerWindow->show();
+//	}
+//}
 
-	// COPY FIELDS
-	for (int i = 0; i < this->target->fields.size(); i++) {
-		TargetField * item = new TargetField(this->target->fields.at(i));
-		fields.append(item);
-
-		//qDebug () << "field " << i << " -> " << item->value;
-	}
-
-	setContextMenuPolicy(Qt::NoContextMenu);
-
-	// Create dialog main layout
-
-	QHBoxLayout * layout = new QHBoxLayout(this);
-
-	layout->setMargin(0);
-	layout->setSpacing(0);
-
-	layout->setSpacing(10);
-	layout->setMargin(10);
-
-	QDialogButtonBox* dlgBtnBox = new QDialogButtonBox(this);
-	dlgBtnBox->setOrientation(Qt::Vertical);
-
-	previousButton = new QPushButton(QIcon(":/resources/icon_previous.png"), "", this);
-	//previousButton->setFixedHeight(70);
-	previousButton->setContextMenuPolicy(Qt::NoContextMenu);
-	previousButton->setFocusPolicy(Qt::NoFocus);
-	previousButton->setIconSize(QSize(48, 48));
-	QObject::connect(previousButton, SIGNAL(clicked()), this, SLOT(previous()));
-	dlgBtnBox->addButton(previousButton, QDialogButtonBox::ActionRole);
-
-	nextButton = new QPushButton(QIcon(":/resources/icon_next.png"), "", this);
-	//nextButton->setFixedHeight(70);
-	nextButton->setContextMenuPolicy(Qt::NoContextMenu);
-	nextButton->setFocusPolicy(Qt::NoFocus);
-	nextButton->setIconSize(QSize(48, 48));
-	QObject::connect(nextButton, SIGNAL(clicked()), this, SLOT(next()));
-	dlgBtnBox->addButton(nextButton, QDialogButtonBox::ActionRole);
-
-	deleteButton = new QPushButton(QIcon(":/resources/icon_delete.png"), "", this);
-	//deleteButton->setFixedHeight(70);
-	deleteButton->setContextMenuPolicy(Qt::NoContextMenu);
-	deleteButton->setFocusPolicy(Qt::NoFocus);
-	deleteButton->setIconSize(QSize(48, 48));
-	QObject::connect(deleteButton, SIGNAL(clicked()), this, SLOT(deleteCurrent()));
-	dlgBtnBox->addButton(deleteButton, QDialogButtonBox::ActionRole);
-
-	QPushButton * newButton = new QPushButton(QIcon(":/resources/icon_add_new.png"), "", this);
-	//newButton->setFixedHeight(70);
-	newButton->setContextMenuPolicy(Qt::NoContextMenu);
-	newButton->setFocusPolicy(Qt::NoFocus);
-	newButton->setIconSize(QSize(48, 48));
-	QObject::connect(newButton, SIGNAL(clicked()), this, SLOT(addNew()));
-	dlgBtnBox->addButton(newButton, QDialogButtonBox::ActionRole);
-
-	QPushButton * closeButton = new QPushButton("Save && Close", this);
-	//closeButton->setFixedHeight(70);
-	closeButton->setContextMenuPolicy(Qt::NoContextMenu);
-	closeButton->setFocusPolicy(Qt::NoFocus);
-	closeButton->setIconSize(QSize(48, 48));
-	QObject::connect(closeButton, SIGNAL(clicked()), this, SLOT(save()));
-	dlgBtnBox->addButton(closeButton, QDialogButtonBox::ActionRole);
-
-	QGridLayout * componentLayout = new QGridLayout ();
-	componentLayout->setContentsMargins(15, 0, 15, 0);
-	componentLayout->setSpacing(5);
-
-	// Name label
-	QLabel * nameLabel = new QLabel(tr("Name"), this);
-	nameLabel->setContextMenuPolicy(Qt::NoContextMenu);
-	//nameLabel->setAlignment(Qt::AlignTop);
-	componentLayout->addWidget(nameLabel, 1, 1, 1, 2);
-
-// Name line edit
-	nameLineEdit = new QLineEdit(this);
-	nameLineEdit->setContextMenuPolicy(Qt::NoContextMenu);
-	//nameLineEdit->setAlignment(Qt::AlignTop);
-
-	componentLayout->addWidget(nameLineEdit, 1, 3, 1, 4);
-
-	// type label
-	QLabel * typeLabel = new QLabel(tr("Type"), this);
-	typeLabel->setContextMenuPolicy(Qt::NoContextMenu);
-	//typeLabel->setAlignment(Qt::AlignTop);
-	componentLayout->addWidget(typeLabel, 2, 1, 1, 2);
-
-	// type line edit
-	typeLineEdit = new QComboBox(this);
-	typeLineEdit->setContextMenuPolicy(Qt::NoContextMenu);
-	//typeLineEdit->setAlignment(Qt::AlignTop);
-
-	typeLineEdit->addItem (tr("String"), QVariant(TYPE_STRING));
-	typeLineEdit->addItem (tr("Text"), QVariant(TYPE_TEXT));
-	typeLineEdit->addItem (tr("Date"), QVariant(TYPE_DATE));
-	typeLineEdit->addItem (tr("Number"), QVariant(TYPE_INTEGER));
-	typeLineEdit->addItem (tr("Phone Number"), QVariant(TYPE_PHONE_NUMBER));
-	typeLineEdit->addItem (tr("Password"), QVariant(TYPE_PASSWORD));
-	typeLineEdit->addItem (tr("URL"), QVariant(TYPE_URL));
-	typeLineEdit->addItem (tr("Image"), QVariant(TYPE_IMAGE));
-
-	componentLayout->addWidget(typeLineEdit, 2, 3, 1, 4);
-
-	// Name label
-	QLabel * orderLabel = new QLabel(tr("Order"), this);
-	orderLabel->setContextMenuPolicy(Qt::NoContextMenu);
-	//nameLabel->setAlignment(Qt::AlignTop);
-	componentLayout->addWidget(orderLabel, 3, 1, 1, 2);
-
-// Name line edit
-	orderEdit = new QLineEdit(this);
-	orderEdit->setContextMenuPolicy(Qt::NoContextMenu);
-	orderEdit->setInputMethodHints(Qt::ImhDigitsOnly);
-	orderEdit->setValidator(new QIntValidator (1, 100, this));
-
-	componentLayout->addWidget(orderEdit, 3, 3, 1, 4);
-
-	layout->addLayout(componentLayout);
-	layout->setAlignment(componentLayout, Qt::AlignVCenter);
-
-	layout->addWidget(dlgBtnBox);
-	layout->setAlignment(dlgBtnBox, Qt::AlignBottom);
-
-	setLayout(layout);
-
-	showField ();
-}
-
-void CreateFieldDialog::update () {
-	if (pos < fields.length()) {
-		int type = typeLineEdit->itemData(typeLineEdit->currentIndex()).toInt();
-		if (orderEdit->isModified() || nameLineEdit->isModified() || type != fields[pos]->type) {
-			int order = QVariant (orderEdit->text()).toInt();
-			fields[pos]->name = nameLineEdit->text();
-			fields[pos]->type = type;
-			fields[pos]->order = order;
-			_fieldsChanged = true;
-		}
+void DetailWindow::showN () {
+	show ();
+	if (!createFieldDlg.isNull()) {
+		createFieldDlg->show();
 	}
 }
-
-void CreateFieldDialog::previous () {
-	if (pos > 0) {
-		update ();
-		pos--;
-		showField ();
+void DetailWindow::hideN () {
+	if (!createFieldDlg.isNull()) {
+		createFieldDlg->hide();
 	}
-}
-void CreateFieldDialog::addNew () {
-	_fieldsChanged = true;
-
-	update ();
-	pos = fields.length();
-	fields.append(new TargetField ("", TYPE_STRING, true, 100));
-
-	showField ();
-}
-void CreateFieldDialog::next () {
-	if ((pos + 1) < fields.length()) {
-		update ();
-		pos++;
-		showField ();
-	}
-}
-void CreateFieldDialog::deleteCurrent () {
-	if (pos >= 0 && pos < fields.length()) {
-		_fieldsChanged = true;
-
-		update ();
-		fields.removeAt(pos);
-		if (pos >= fields.length()) {
-			pos--;
-			if (pos < 0) pos = 0;
-		}
-		showField ();
-	}
-	else {
-		nameLineEdit->hide ();
-		typeLineEdit->hide ();
-		orderEdit->hide ();
-	}
-}
-
-void CreateFieldDialog::showField () {
-	if (pos < fields.length()) {
-		if (!nameLineEdit->isEnabled()) {
-			nameLineEdit->setDisabled(false);
-			typeLineEdit->setDisabled(false);
-			orderEdit->setDisabled(false);
-		}
-	}
-	else {
-		if (nameLineEdit->isEnabled()) {
-			nameLineEdit->setText("");
-			orderEdit->setText("");
-
-			nameLineEdit->setDisabled(true);
-			typeLineEdit->setDisabled(true);
-			orderEdit->setDisabled(true);
-		}
-	}
-
-	if (pos == 0) {
-		previousButton->setDisabled(true);
-	}
-	else {
-		previousButton->setDisabled(false);
-	}
-	if ((pos + 1) >= fields.length()) {
-		nextButton->setDisabled(true);
-	}
-	else {
-		nextButton->setDisabled(false);
-	}
-	if (pos >= 0 && pos < fields.length()) {
-		deleteButton->setDisabled(false);
-	}
-	else {
-		deleteButton->setDisabled(true);
-	}
-	if (pos < fields.length()) {
-		nameLineEdit->setText(fields[pos]->name);
-		int i = typeLineEdit->findData(QVariant (fields[pos]->type));
-		typeLineEdit->setCurrentIndex(i);
-		orderEdit->setText(QString::number(fields[pos]->order));
-	}
-}
-
-void CreateFieldDialog::save () {
-	update ();
-
-	if (_fieldsChanged) {
-		// REMOVE PREVIOUS
-		for (int i = 0; i < this->target->fields.size(); i++) {
-			TargetField * item = this->target->fields.at(i);
-
-			delete item;
-		}
-		this->target->fields.clear();
-
-		// RECOVER FIELDS
-		for (int i = 0; i < fields.size(); i++) {
-			TargetField * item = new TargetField(fields.at(i));
-			this->target->fields.append(item);
-
-			//qDebug () << "field " << i << " -> " << item->value;
-		}
-
-		parent->fieldsChanged = _fieldsChanged;
-	}
-
-	close();
-}
-
-CreateFieldDialog::~CreateFieldDialog() {
-	for (int i = 0; i < fields.size(); i++) {
-		TargetField * item = fields.at(i);
-		delete item;
-	}
-
-	fields.clear();
+	hide ();
 }
