@@ -12,54 +12,14 @@
 
 #include "DatabaseManager.h"
 #include "DetailedWindow.h"
+#include "OptionsDialog.h"
+#include "RenameGroupDialog.h"
+#include "DetailedWindow.h"
 #include "LoginDialog.h"
-
-
+#include "EditTemplates.h"
 
 extern DatabaseManager * dbManager;
 
-class OptionsDialog: public QDialog {
-	Q_OBJECT
-
-public:
-	OptionsDialog(QWidget *parent = 0);
-	~OptionsDialog();
-
-private:
-	QSettings settings;
-	QCheckBox * fixImageSize;
-	QCheckBox * phoneChars;
-
-	QSpinBox * maxWidth;
-	QSpinBox * maxHeigh;
-
-	QComboBox * typeImageSize;
-
-private slots:
-	void changeFix ();
-	void changePhoneChars ();
-	void valueChangedW (int i);
-	void valueChangedH (int i);
-};
-
-
-class RenameGroupDialog: public QDialog {
-	Q_OBJECT
-
-public:
-	RenameGroupDialog (QWidget *parent = 0);
-	~RenameGroupDialog ();
-
-	void setName (const QString & name);
-	QString getName ();
-
-private slots:
-	void save ();
-
-private:
-	QLineEdit * nameLineEdit;
-};
-
 class eWallet: public QMainWindow
 {
 	Q_OBJECT
@@ -72,8 +32,6 @@ public:
 
 	static void preProcessImage (QImage * image);
 
-	bool finalPassword (const QString & pas);
-
 	bool _deleteTarget(Target* target);
 	bool _updateTarget(Target* target);
 	bool _updateTargetPicture(Target* target);
@@ -81,8 +39,11 @@ public:
 	bool _insertTarget(Target* target);
 	bool __insertTarget(Target* target);
 	
-	QList<QString> * types;
-	QList<QList<TargetField>*> * fieldsByType;
+	QList<Target*> * types;
+	//QList<QList<TargetField*>*> * fieldsByType;
+
+	void showN ();
+	void hideN ();
 
 public slots:
 	void newTarget();
@@ -102,6 +63,8 @@ private:
 ////	void swipeTriggered (QSwipeGesture *gesture);
 //	bool gestureEvent (QGestureEvent *event);
 
+	void initTemplates ();
+
 	bool openDataBase (const QString & pas);
 	void showList (bool interactive);
 	void keyPressEvent(QKeyEvent*);
@@ -109,18 +72,31 @@ private:
 	void showGroups(bool reset);
 	void showInfo(bool reset);
 	void showTargets(bool reset, const QString * filter);
+
 	void loadTypesAndFields ();
+	void _loadTypesAndFields (QList<Target*> * types); //, QList<QList<TargetField*>*> * fieldsByType);
+
 	void filterBy (const QString & s);
 	QPixmap getImage (Target * f);
+
 	bool isAskPassword;
 	bool isChangingPassword;
+
     void reallyChangePassword (const QString & newPassword);
 
 private slots:
+	void finalPassword (const QString pas);
+	void finalChangePassword (const QString pas);
+	void finalUnlock (const QString pas);
+
 	void orientationChanged(int);
     void windowDestroyed(QObject* obj = 0);
     void windowDestroyedExtra(QObject* obj = 0);
     void windowDestroyedEdit(QObject* obj = 0);
+    void windowDestroyedTemplates(QObject* obj = 0);
+
+    void editTemplates();
+
     void sort ();
     void changePassword ();
 
@@ -147,14 +123,19 @@ private slots:
 	void contextMenuEvent (QContextMenuEvent * event);
 	void renameGroup ();
 	void deleteGroup ();
-	
+
+	void createDatabase ();
+	void migrateDatabase (int from, int to);
+
 private:
 	QSettings settings;
 	QPointer<OptionsDialog> optionsDlg;
 
 	void askPassword ();
+	void askAgainPassword ();
 	void closeEvent(QCloseEvent *event);
 	bool isFirst;
+	bool isUnLockMode;
 	QVBoxLayout * vboxlayout;
 	int times;
 	QListWidget* fnListWidget;
@@ -167,6 +148,7 @@ private:
 	QLineEdit * searchField;
 	//QPushButton * backButton;
 
+	QPointer<EditTemplates> templatesWindow;
 	QPointer<LoginDialog> loginDialogDlg;
 	QPointer<DetailWindow> detailWindow;
 	QPointer<DetailWindow> detailWindowEdit;
